@@ -7,6 +7,11 @@ test_that("primeFactorizeSieve generates correct numbers", {
     expect_equal(primeFactorizeSieve(2)[[2]], 2)
     expect_equal(primeFactorizeSieve(2, 2)[[1]], 2)
     expect_equal(primeFactorizeSieve(1000, 1000)[[1]], c(2,2,2,5,5,5))
+    expect_equal(length(primeFactorizeSieve(1L, namedList = TRUE)[[1]]), 0)
+    expect_equal(length(primeFactorizeSieve(1L, 1L, namedList = TRUE)[[1]]), 0)
+    
+    a <- primeFactorizeSieve(1e12+10, 1e12, namedList = TRUE)
+    expect_true(all(sapply(a, prod) == as.numeric(names(a))))
     
     ## Test Names
     expect_equal(as.integer(names(primeFactorizeSieve(100, namedList = TRUE))), 1:100)
